package javax.swing;

import sun.swing.ImageIconUIResource;
import javax.swing.plaf.ColorUIResource;
import javax.swing.plaf.FontUIResource;
import java.awt.Toolkit;
import java.awt.Component;
import sun.swing.DefaultLayoutStyle;
import sun.swing.SwingUtilities2;
import javax.swing.plaf.ComponentInputMapUIResource;
import javax.swing.plaf.InputMapUIResource;
import javax.swing.text.JTextComponent;
import sun.awt.SunToolkit;
import javax.swing.border.Border;
import java.awt.Font;
import java.awt.Color;
import javax.swing.plaf.UIResource;

public abstract class LookAndFeel
{
    public LookAndFeel() {
    }
    
    public static void installColors(JComponent component, String s, String s2) {
        Color background = component.getBackground();
        if (background == null || background instanceof UIResource) {
            component.setBackground(UIManager.getColor(s));
        }
        Color foreground = component.getForeground();
        if (foreground == null || foreground instanceof UIResource) {
            component.setForeground(UIManager.getColor(s2));
        }
    }
    
    public static void installColorsAndFont(JComponent component, String s, String s2, String s3) {
        Font font = component.getFont();
        if (font == null || font instanceof UIResource) {
            component.setFont(UIManager.getFont(s3));
        }
        installColors(component, s, s2);
    }
    
    public static void installBorder(JComponent component, String s) {
        Border border = component.getBorder();
        if (border == null || border instanceof UIResource) {
            component.setBorder(UIManager.getBorder(s));
        }
    }
    
    public static void uninstallBorder(JComponent component) {
        if ((component.getBorder() instanceof UIResource)) {
            component.setBorder(null);
        }
    }
    
    public static void installProperty(JComponent obj, String s, Object o) {
        if (SunToolkit.isInstanceOf(obj, "javax.swing.JPasswordField")) {
            if (!((JPasswordField)obj).customSetUIProperty(s, o)) {
                obj.setUIProperty(s, o);
            }
        }
        else {
            obj.setUIProperty(s, o);
        }
    }
    
    public static JTextComponent.KeyBinding[] makeKeyBindings(Object[] array) {
        JTextComponent.KeyBinding[] array2 = new JTextComponent.KeyBinding[array.length / 2];
        for (int i = 0; i < array2.length; ++i) {
            Object o = array[2 * i];
            array2[i] = new JTextComponent.KeyBinding((o instanceof KeyStroke) ? ((KeyStroke)o) : KeyStroke.getKeyStroke((String)o), (String)array[2 * i + 1]);
        }
        return array2;
    }
    
    public static InputMap makeInputMap(Object[] array) {
        InputMapUIResource inputMapUIResource = new InputMapUIResource();
        loadKeyBindings(inputMapUIResource, array);
        return inputMapUIResource;
    }
    
    public static ComponentInputMap makeComponentInputMap(JComponent component, Object[] array) {
        ComponentInputMapUIResource componentInputMapUIResource = new ComponentInputMapUIResource(component);
        loadKeyBindings(componentInputMapUIResource, array);
        return componentInputMapUIResource;
    }
    
    public static void loadKeyBindings(InputMap inputMap, Object[] array) {
        if (array != null) {
            for (int i = 0; i < array.length; ++i) {
                Object o = array[i++];
                inputMap.put((o instanceof KeyStroke) ? ((KeyStroke)o) : KeyStroke.getKeyStroke((String)o), array[i]);
            }
        }
    }
    
    public static Object makeIcon(Class<?> clazz, String imageFile) {
        return SwingUtilities2.makeIcon(clazz, clazz, imageFile);
    }
    
    public LayoutStyle getLayoutStyle() {
        return DefaultLayoutStyle.getInstance();
    }
    
    public void provideErrorFeedback(Component component) {
        Toolkit toolkit;
        if (component != null) {
            toolkit = component.getToolkit();
        }
        else {
            toolkit = Toolkit.getDefaultToolkit();
        }
        toolkit.beep();
    }
    
    public static Object getDesktopPropertyValue(String propertyName, Object o) {
        Object desktopProperty = Toolkit.getDefaultToolkit().getDesktopProperty(propertyName);
        if (desktopProperty == null) {
            return o;
        }
        if ((desktopProperty instanceof Color)) {
            return new ColorUIResource((Color)desktopProperty);
        }
        if ((desktopProperty instanceof Font)) {
            return new FontUIResource((Font)desktopProperty);
        }
        return desktopProperty;
    }
    
    public Icon getDisabledIcon(JComponent component, Icon icon) {
        if ((icon instanceof ImageIcon)) {
            return new ImageIconUIResource(GrayFilter.createDisabledImage(((ImageIcon)icon).getImage()));
        }
        return null;
    }
    
    public Icon getDisabledSelectedIcon(JComponent component, Icon icon) {
        return this.getDisabledIcon(component, icon);
    }
    
    public abstract String getName();
    
    public abstract String getID();
    
    public abstract String getDescription();
    
    public boolean getSupportsWindowDecorations() {
        return false;
    }
    
    public abstract boolean isNativeLookAndFeel();
    
    public abstract boolean isSupportedLookAndFeel();
    
    public void initialize() {
    }
    
    public void uninitialize() {
    }
    
    public UIDefaults getDefaults() {
        return null;
    }
    
    @Override
    public String toString() {
        return "[" + this.getDescription() + " - " + this.getClass().getName() + "]";
    }
}
